pub struct DecoderConfig {
pub luma_only: bool,
}Expand description
A set of possible configuration flags that are generic across all decoders.
Fields
luma_only: boolIf true, the decoder will only fetch the luma planes from the video.